# Generated by Django 3.2.10 on 2022-01-25 11:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('galleryserve', '0002_gallery_random'),
    ]

    operations = [
        migrations.AlterField(
            model_name='gallery',
            name='height',
            field=models.IntegerField(blank=True, default=600, help_text='Height images should be resized to in pixels'),
        ),
        migrations.AlterField(
            model_name='gallery',
            name='quality',
            field=models.IntegerField(default=85, help_text='An integer between 0-100. 100 will result in the largest file size.', verbose_name='Image Quality'),
        ),
        migrations.AlterField(
            model_name='gallery',
            name='random',
            field=models.BooleanField(default=False, help_text='If selected, the sort numbers will be ignored and your gallery objects will be generated in random order.'),
        ),
        migrations.AlterField(
            model_name='gallery',
            name='resize',
            field=models.BooleanField(default=True, help_text='If selected, the dimensions specified above will be used to scale and crop the uploaded image'),
        ),
        migrations.AlterField(
            model_name='gallery',
            name='width',
            field=models.IntegerField(blank=True, default=800, help_text='Width images should be resized to in pixels'),
        ),
        migrations.AlterField(
            model_name='item',
            name='alt',
            field=models.CharField(blank=True, help_text='This will be used for the image alt attribute', max_length=100),
        ),
        migrations.AlterField(
            model_name='item',
            name='content',
            field=models.TextField(blank=True, help_text='Use this field to add html content associated with the item'),
        ),
        migrations.AlterField(
            model_name='item',
            name='credit',
            field=models.CharField(blank=True, help_text='Use this field to credit the image or content creator', max_length=200),
        ),
        migrations.AlterField(
            model_name='item',
            name='image',
            field=models.ImageField(blank=True, upload_to='galleryserve/images'),
        ),
        migrations.AlterField(
            model_name='item',
            name='sort',
            field=models.IntegerField(default=0, help_text='Items will be displayed in their sort order'),
        ),
        migrations.AlterField(
            model_name='item',
            name='title',
            field=models.CharField(blank=True, help_text='This will be used for the image or content title attribute', max_length=100),
        ),
        migrations.AlterField(
            model_name='item',
            name='url',
            field=models.CharField(blank=True, help_text='URL to which the image will be linked.', max_length=200, verbose_name='target url'),
        ),
        migrations.AlterField(
            model_name='item',
            name='video_url',
            field=models.URLField(blank=True, help_text='Enter the url of the video to be embedded', verbose_name='video url'),
        ),
    ]
